============================
geoffrey-pytest
============================

.. image:: https://badge.fury.io/py/geoffrey-pytest.png
    :target: http://badge.fury.io/py/geoffrey-pytest
    
.. image:: https://travis-ci.org/nilp0inter/geoffrey-pytest.png?branch=master
        :target: https://travis-ci.org/nilp0inter/geoffrey-pytest

.. image:: https://pypip.in/d/geoffrey-pytest/badge.png
        :target: https://pypi.python.org/pypi/geoffrey-pytest


Geoffrey pytest plugin runner.

* Free software: GPLv3
* Documentation: http://geoffrey-pytest.readthedocs.org.

Features
--------

* TODO